<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Fundraising;
use App\User;
use App\Blog;
use Image;
use App\Faq;
use App\Banner;
use App\Contact;
use App\About;
use Auth;
use DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Carbon\Carbon;
use App\Testimonial;
use App\BlogImage;

use App\Subscription;
use App\SubscriptionPlan;
use App\Payment;
use App\Exports\UsersExport;

class AdminController extends Controller
{
    
    public function index(){

        $todayDate = Carbon::today();
        $yesterday = Carbon::today()->subDays(2);
        $lastSevenDays = Carbon::today()->subDays(7);
        $lastThirtyDays = Carbon::today()->subDays(30);
        $last365Days = Carbon::today()->subDays(365);


        $today_subscription_no = Subscription::where('created_at',$todayDate)->count();
        $today_subscription_revenue = Subscription::where('created_at',$todayDate)->sum('amount');

        $total_subscription_revenue = Subscription::sum('amount');
        $total_subscription_no = Subscription::count();

        $yesterday_subscription_revenue = Subscription::where('created_at',$yesterday)->sum('amount');
        $yesterday_subscription_no = Subscription::where('created_at',$yesterday)->count();
        
        $week_subscription_revenue = Subscription::where('created_at', '>=', '$lastSevenDays')->sum('amount');
        $week_subscription_no = Subscription::where('created_at', '>=', '$lastSevenDays')->count();
        
        $month_subscription_revenue = Subscription::whereDate('created_at', '>=', '$lastThirtyDays')->sum('amount');
        $month_subscription_no = Subscription::whereDate('created_at', '>=', '$lastThirtyDays')->count();
        
        $year_subscription_revenue = Subscription::whereDate('created_at', '>=', '$last365Days')->sum('amount');
        $year_subscription_no = Subscription::whereDate('created_at', '>=', '$last365Days')->count();


        $total_unapproved_Subscriptions = Subscription::where('status','New')->count();
        $total_Approved_Subscriptions = Subscription::where('status','Approved')->count();
        $total_ended_Subscriptions = Subscription::where('end_date', '<', Carbon::now())->count();
        $total_active_Subscriptions = Subscription::where('end_date', '>', Carbon::now())->count();
        $total_users = User::count();
        $total_admins = User::where('user_type','Admin')->count();
        $total_normal_users = User::where('user_type','User')->count();
        

        return view('admin.index')->with(compact('today_subscription_no','today_subscription_revenue','total_subscription_revenue','total_subscription_no','yesterday_subscription_revenue','yesterday_subscription_no','week_subscription_revenue','week_subscription_no','month_subscription_revenue','month_subscription_no','year_subscription_revenue','year_subscription_no','total_unapproved_Subscriptions','total_Approved_Subscriptions','total_ended_Subscriptions','total_active_Subscriptions','total_active_Subscriptions','total_users','total_admins','total_normal_users'));
    }
    public function send_mail(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>"; print_r( $data);die();
         

            $email = $data['email'];
            $messageData = [
                
                'email'=>$data['email'],
                'subject'=>$data['subject'],
                'comment'=>$data['summernoteInput']
            ];
            Mail::send('emails.mail_send',$messageData,function($message)use($email,$data){
                $message->to($email)->subject($data['subject']);
            });

           
            return redirect()->back()->with('flash_message_success', 'Mail Sent');
        }


        return view('admin.send_mail');

    }
    
    public function subscription_plans(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>";print_r($data);die();
            $subscription_plan = new SubscriptionPlan;
            $subscription_plan->name = $data['name'];
            $subscription_plan->description = $data['summernoteInput'];
            $subscription_plan->validity = $data['validity'];
            $subscription_plan->type = $data['type'];
            $subscription_plan->amount = $data['amount'];
            $subscription_plan->status = $data['status'];
            $subscription_plan->save();
            return redirect()->back()->with('flash_message_success','SubscriptionPlan Added Successfully!');
        }

        $page_name = 'Create Subscription';
        $page_link = '/admin/create_subscription';



        $subscription_plans = SubscriptionPlan::get();
        
        return view('admin.subscription.plans')->with(compact('subscription_plans','page_name','page_link' ));
    }

    public function editplan(Request $request, $id){
        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>";print_r($data);die();

            SubscriptionPlan::where('id', $id)->update(['name'=>$data['name'],'amount'=>$data['amount'],'validity'=>$data['validity'], 'description'=>$data['summernoteInput'],'Type'=>$data['type'], 'status'=>$data['status']]);

            return redirect('/admin/create_subscription')->with('flash_message_success','Plan Updated');
        }
        $subscription_plan = SubscriptionPlan::where('id', $id)->get()->first();
        return view('admin.subscription.edit_subscription')->with(compact('subscription_plan'));
    }

    public function deleteplan($id){

        SubscriptionPlan::where('id', $id)->delete();
        $arr = array('status'=>true);
        return response()->json('success');
    }
    public function unapproved_subscription(Request $request){

        $unapproved_subscriptions = Subscription::where('status', 'New')->get();
        return view('admin.subscription.unapproved_subscription');
    }
    public function delete_unapproved_subscription($id){

        Subscription::where('id', $id)->delete();
        return redirect()->back()->with('flash_message_success', 'Deleted');
    }
    public function approve_subscription(Request $request, $id){

        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>"; print_r( $data);die();
            //echo $id; die();


            $email = $data['email'];
            $messageData = [
                'name'=>$data['name'],
                'email'=>$data['email'],
                'subject'=>$data['subject'],
                'comment'=>$data['summernoteInput']
            ];
            Mail::send('emails.approval',$messageData,function($message)use($email,$data){
                $message->to($email)->subject($data['subject']);
            });
            $subscription = Subscription::where('id',$id)->first();
            $plan_id = $subscription->plan_id;
            $plan = SubscriptionPlan::where('id', $plan_id)->first();
            $plan_validity = $plan->validity;
            $end_date = Carbon::now()->addDays($plan_validity);


            Subscription::where('id', $id)->update(['status'=>'Approved','end_date'=>$end_date]);
            return redirect('admin/unapproved_subscription')->with('flash_message_success', 'Subscription Approved');
        }

        $subscription = Subscription::where('id', $id)->first();
        return view('admin.subscription.approve_subscription')->with(compact('subscription'));
    }
    public function active_subscription(){

        $page_name = 'Subscriptions';
        $page_link = '/admin/active_subscription';
        $subscriptions = Subscription::get();
        return view('admin.subscription.active_subscription')->with(compact('subscriptions','page_name','page_link'));
    }
    public function delete_subscription($id){
        Subscription::where('id', $id)->delete();
        return redirect()->back()->with('flash_message_success', 'Deleted');
    }
    public function payments(Request $request){
        $page_name = 'Payments';
        $page_link = '/admin/payments';

        $payments = Payment::get();
        return view('admin.payment')->with(compact('payments','page_name','page_link'));
    }
    public function delete_payment($id){
        Payment::where('id', $id)->delete();
        return redirect()->back()->with('flash_message_success', 'Deleted'); 
    }
    public function personal_information(Request $request){

        if($request->isMethod('post')){
            
            $data = $request->all();
           
            if($request->hasFile('profile_avatar'))
            {
                $image_tmp = $request->profile_avatar;
                if ($image_tmp->isValid()) 
                {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $large_image_path = 'images/backend_images/users/large'.'/'.$fileName;
                    $medium_image_path = 'images/backend_images/users/medium'.'/'.$fileName;  
                    $small_image_path = 'images/backend_images/users/small'.'/'.$fileName;  

                    Image::make($image_tmp)->save($large_image_path);
                    Image::make($image_tmp)->resize(600, 600)->save($medium_image_path);
                    Image::make($image_tmp)->resize(300, 300)->save($small_image_path);

                }
            }elseif(!empty($data['current_image']))
            {
                $fileName = $data['current_image'];
            }else
            {
                $fileName = '';
            }


            User::where('id',Auth::User()->id)->update([ 
                'name'=>$data['name'],
                'mobile'=>$data['mobile'], 
                'image'=>$fileName 
            ]);
                
            return redirect()->back()->with('flash_message_success',' Profile updated successfully!');
        
        }

        $page_name = 'Personal Information';
        $page_link = '/admin/personal_information';
        
        $user = User::where('id', Auth::user()->id)->first();
        return view('admin.settings.personal_information')->with(compact('user','page_link','page_name'));
    }
    public function change_password(Request $request){

        if($request->isMethod('post')){
            
            $data = $request->all();
            // echo "<pre>"; print_r($data); die;
            
            $old_pwd = User::where('id',Auth::User()->id)->first();
            $current_pwd = $data['password'];
            
            if(Hash::check($current_pwd,$old_pwd->password)){
                // Update password
                $new_pwd = bcrypt($data['new_password']);

                User::where('id',Auth::User()->id)->update([ 'password'=>$new_pwd]);

                return redirect()->back()->with('flash_message_success',' Password updated successfully!');
            }else{
                return redirect()->back()->with('flash_message_error','Current Password is incorrect!');
            }
        
        }

        $page_name = 'Change Password';
        $page_link = '/admin/change_password';
        
        $user = User::where('id', Auth::user()->id)->first();
        return view('admin.settings.change_password')->with(compact('user','page_link','page_name'));
    }
    public function users(Request $request){
        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>";print_r($data);die();
            $user = new User;
            $user->name = $data['name'];
            $user->mobile = $data['mobile'];
            $user->email = $data['email'];
            $user->user_type = $data['user_type'];
            $user->status = $data['status'];
            $user->password = bcrypt($data['password']);
            $user->save();

            return redirect()->back()->with('flash_message_success','User Added');
        }
        $users = User::get();
        return view('admin.users.index')->with(compact('users'));
    }

    public function edituser(Request $request, $id){
        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>";print_r($data);die();


            User::where('id', $id)->update(['name'=>$data['name'], 'mobile'=>$data['mobile'], 'email'=>$data['email'], 'user_type'=>$data['user_type'], 'status'=>$data['status']  ]);

            return redirect()->back()->with('flash_message_success','User updated');
        }
        $user = User::where('id', $id)->get()->first();
        return view('admin.users.edituser')->with(compact('user'));
    }

    public function deleteuser($id){

        User::where('id', $id)->delete();
        return redirect('/admin/users')->with('flash_message_success','User Deleted');
    }

    
   

    public function download($filename){

        //echo $filename;die();

        // Check if file exists in app/storage/file folder
        $file_path = storage_path() .'/tmp/uploads/'. $filename;
        echo $file_path;
        if (file_exists($file_path))
        {   
            //echo "yes";die();
                // Send Download
            return response()->download($file_path, $filename, [
                'Content-Length: '. filesize($file_path)
            ]);
        }
        else
        {
            // Error
            exit('Requested file does not exist on our server!');
        }


    }



    public function donors(){

    	$donors = Donation::get();
    	return view('admin.donation.index')->with(compact('donors'));
    }

    public function add_fundraising_category(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>";print_r($data);die();
            $category = new Category;
            $category->name = $data['name'];
            if($request->hasFIle('image')){
                //echo "hello";die();
                $image_tmp = $request->image;

                if ($image_tmp->isValid()) {
                    //upload images after resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $large_image_path = 'images/backend_images/category/large'.'/'.$fileName;
                    $medium_image_path = 'images/backend_images/category/medium'.'/'.$fileName;
                    $small_image_path = 'images/backend_images/category/small'.'/'.$fileName;

                    Image::make($image_tmp)->save($large_image_path);
                    Image::make($image_tmp)->resize(600,600)->save($medium_image_path);
                    Image::make($image_tmp)->resize(300,300)->save($small_image_path);

                    $category->image = $fileName;
                }
            }
            $category->save();
            return redirect()->back()->with('flash_message_success','Category Added');
        }
        $categories = Category::get();
        return view('admin.fundraising.fundraising_category')->with(compact('categories'));

    }

    public function deletecategory($id){

        Category::where('id',$id)->delete();
        return redirect()->back()->with('flash_message_success','Category Deleted');
    }




    public function faq(Request $request){
        if($request->isMethod('post')){
            
            $detail=$request->summernoteInput;

            $dom = new \domdocument();
            $dom->loadHtml($detail, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
            $images = $dom->getelementsbytagname('img');

            //loop over img elements, decode their base64 src and save them to public folder,
            //and then replace base64 src with stored image URL.
            foreach($images as $k => $img){
                $data = $img->getattribute('src');

                list($type, $data) = explode(';', $data);
                list(, $data)      = explode(',', $data);

                $data = base64_decode($data);
                $image_name= time().$k.'.png';
                $path = public_path() .'/'. $image_name;

                file_put_contents($path, $data);

                $img->removeattribute('src');
                $img->setattribute('src', $image_name);
            }

            $detail = $dom->savehtml();
            $faq = new Faq;
            $faq->answer = $detail;
            $faq->question = $request->question;
            $faq->save();
         

            return redirect()->back()->with('flash_message_success','Faq Added Successfully.');

        }
        $faqs = Faq::get();
        return view('admin.faq.index')->with(compact('faqs'));
    }

    public function deleteFaq($id){
        Faq::where(['id'=>$id])->delete();
        return redirect()->back()->with('flash_message_success','Faq Deleted');
    }

    public function editFaq($id){

        $faq = Faq::where(['id'=>$id])->get()->first();
        return view('admin.faq.editFaq')->with(compact('faq'));
    }

    public function updateFaq(Request $request, $id){
        $detail=$request->summernoteInput;

        $dom = new \domdocument();
        $dom->loadHtml($detail, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
        $images = $dom->getelementsbytagname('img');

        //loop over img elements, decode their base64 src and save them to public folder,
        //and then replace base64 src with stored image URL.
        foreach($images as $k => $img){
            $data = $img->getattribute('src');

            list($type, $data) = explode(';', $data);
            list(, $data)      = explode(',', $data);

            $data = base64_decode($data);
            $image_name= time().$k.'.png';
            $path = public_path() .'/'. $image_name;

            file_put_contents($path, $data);

            $img->removeattribute('src');
            $img->setattribute('src', $image_name);
        }

        $detail = $dom->savehtml();

        Faq::where(['id'=>$id])->update([
            'question' => $request->question,
            'answer' => $request->summernoteInput
        ]);

        return redirect('/admin/faq')->with('flash_message_success','Faq updated Successfully');
    }



    // blog functions
    public function blogs(Request $request){
        if($request->isMethod('post')){
            
            $data=$request->all();
            //echo "<pre>";print_r($data);die();

            $detail=$request->summernoteInput;
            libxml_use_internal_errors(true);
            $dom = new \domdocument();
            $dom->loadHtml($detail, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
            $images = $dom->getElementsByTagName('img');
            //loop over img elements, decode their base64 src and save them to public folder,
            //and then replace base64 src with stored image URL.
            foreach($images as $k => $img){
                $src = $img->getattribute('src');
                if (preg_match('/data:img/', $src)) {
                    preg_match('/data:img\/(?<mime>.*?)\;/', $src, $groups);
                    $mimeType = $groups['mime'];
                    $path = '/images/' . uniqid('', true) . '.' . $mimeType;
                    file_put_cotents($path, file_get_contents($src));
                    $image->removeAttribute('src');
                    $image->setAttribute('src', url($path));
                }
                //list($type, $data) = explode(';', $data);
                //list(, $data)      = explode(',', $data);

                //$data = base64_decode($data);
                //$image_name= time().$k.'.png';
                //$path = public_path() .'/'. $image_name;

                //file_put_contents($path, $data);

                //$img->removeattribute('src');
                //$img->setattribute('src', $image_name);
            }

            $detail = $dom->savehtml();
            $blog = new Blog;
            $blog->description = $detail;
            $blog->title = $request->question;
            $blog->status = $request->status;
            //echo "ok";die();
            if($request->hasFIle('image')){
                //echo "hello";die();
                $image_tmp = $request->image;

                if ($image_tmp->isValid()) {
                    //upload images after resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $large_image_path = 'images/backend_images/blog/large'.'/'.$fileName;
                    $medium_image_path = 'images/backend_images/blog/medium'.'/'.$fileName;
                    $small_image_path = 'images/backend_images/blog/small'.'/'.$fileName;

                    Image::make($image_tmp)->save($large_image_path);
                    Image::make($image_tmp)->resize(600,600)->save($medium_image_path);
                    Image::make($image_tmp)->resize(300,300)->save($small_image_path);

                    $blog->image = $fileName;
                }
            }
            $blog->save();
            
            $blog_id = DB::getPdo()->lastInsertId();
            


            return redirect()->back()->with('flash_message_success','blog Added Successfully.');

        }
        $blogs = blog::get();
        return view('admin.blog.index')->with(compact('blogs'));
    }

    public function deleteblog($id){
        Blog::where(['id'=>$id])->delete();
        return redirect()->back()->with('flash_message_success','blog Deleted');
    }

    public function editBlog($id){

        $blog = Blog::where(['id'=>$id])->get()->first();
        //echo "<pre>";print_r($blog);die();
        return view('admin.blog.editBlog')->with(compact('blog'));
    }

    public function updateblog(Request $request, $id){
        
        $data = $request->all();
        //echo "<pre>";print_r($data);die();      
        $detail=$request->summernoteInput;
        libxml_use_internal_errors(true);
        $dom = new \domdocument();
        $dom->loadHtml($detail, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
        $images = $dom->getElementsByTagName('img');

        //loop over img elements, decode their base64 src and save them to public folder,
        //and then replace base64 src with stored image URL.
        foreach($images as $k => $img){
            $src = $img->getattribute('src');

            if (preg_match('/data:img/', $src)) {
                preg_match('/data:img\/(?<mime>.*?)\;/', $src, $groups);
                $mimeType = $groups['mime'];
                $path = '/images/' . uniqid('', true) . '.' . $mimeType;
                file_put_cotents($path, file_get_contents($src));
                $image->removeAttribute('src');
                $image->setAttribute('src', url($path));
            }
            //list($type, $data) = explode(';', $data);
            //list(, $data)      = explode(',', $data);

            //$data = base64_decode($data);
            //$image_name= time().$k.'.png';
            //$path = public_path() .'/'. $image_name;

            //file_put_contents($path, $data);

            //$img->removeattribute('src');
            //$img->setattribute('src', $image_name);
        }

        $detail = $dom->savehtml();

        // Upload Image
        if($request->hasFile('image'))
        {
            $image_tmp = $request->image;
            if ($image_tmp->isValid()) 
            {
                // Upload Images after Resize
                $extension = $image_tmp->getClientOriginalExtension();
                $fileName = rand(111,99999).'.'.$extension;
                $large_image_path = 'images/backend_images/blog/large'.'/'.$fileName;
                $medium_image_path = 'images/backend_images/blog/medium'.'/'.$fileName;  
                $small_image_path = 'images/backend_images/blog/small'.'/'.$fileName;  

                Image::make($image_tmp)->save($large_image_path);
                Image::make($image_tmp)->resize(600, 600)->save($medium_image_path);
                Image::make($image_tmp)->resize(300, 300)->save($small_image_path);

            }
        }elseif(!empty($data['current_image']))
        {
            $fileName = $data['current_image'];
        }else
        {
            $fileName = '';
        }


        Blog::where(['id'=>$id])->update([
            'title' => $request->question,
            'image' => $fileName,
            'status' =>$request->status,
            'Description' => $detail
        ]);

        return redirect('/admin/blogs')->with('flash_message_success','blog updated Successfully');
    }


    public function blogPost($id){

        $blog = Blog::where(['id'=>$id])->get()->first();
        $relatedBlogs = Blog::inRandomOrder()->where('id','!=',$id)->paginate(3);
        return view('pages.blogPost')->with(compact('blog','relatedBlogs'));
    }

    public function deleteBlogImage($id){

        // Get Product Image
        $blogImage = Blog::where('id',$id)->first();

        // Get Product Image Paths
        $large_image_path = 'images/backend_images/blog/large/';
        $medium_image_path = 'images/backend_images/blog/medium/';
        $small_image_path = 'images/backend_images/blog/small/';

        // Delete Large Image if not exists in Folder
        if(file_exists($large_image_path.$blogImage->image)){
            unlink($large_image_path.$blogImage->image);
        }

        // Delete Medium Image if not exists in Folder
        if(file_exists($medium_image_path.$blogImage->image)){
            unlink($medium_image_path.$blogImage->image);
        }

        // Delete Small Image if not exists in Folder
        if(file_exists($small_image_path.$blogImage->image)){
            unlink($small_image_path.$blogImage->image);
        }

        // Delete Image from blogs table
        Blog::where(['id'=>$id])->update(['image'=>'']);

        return redirect()->back()->with('flash_message_success', 'blog image has been deleted successfully');

    }


    public function banners(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();

            //echo "<pre>";print_r($data);die();
            $banner = new Banner;
            $banner->heading = $data['heading'];
            $banner->subheading = $data['subheading'];
            if(empty($data['status'])){
                $status='0';
            }else{
                $status='1';
            }

            // Upload Image
            if($request->hasFile('image')){
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $banner_path = 'images/banners/'.$fileName;
                    Image::make($image_tmp)->resize(1350, 650)->save($banner_path);
                    $banner->image = $fileName; 
                }
            }

            $banner->status = $status;
            $banner->save();
            return redirect()->back()->with('flash_message_success', 'Banner has been added successfully');
        
        }

        $banners = Banner::get();
        return view('admin.settings.banners.index')->with(compact('banners'));
    }

    public function editBanner(Request $request, $id=null){
        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>"; print_r($data); die;

            if(empty($data['status'])){
                $status='0';
            }else{
                $status='1';
            }

            if(empty($data['heading'])){
                $data['heading'] = '';
            }

            if(empty($data['subheading'])){
                $data['subheading'] = '';
            }

          
            // Upload Image
            if($request->hasFile('image')){
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $banner_path = 'images/banners/'.$fileName;
                    Image::make($image_tmp)->resize(1350, 650)->save($banner_path); 
                }
            }else if(!empty($data['current_image'])){
                $fileName = $data['current_image'];
            }else{
                $fileName = '';
            }


            Banner::where('id',$id)->update(['status'=>$status,'heading'=>$data['heading'], 'subheading'=>$data['subheading'],'image'=>$fileName]);
            return redirect('/admin/banners')->with('flash_message_success','Banner has been edited Successfully');

        }

        $bannerDetails = Banner::where('id',$id)->first();
        return view('admin.settings.banners.editBanner')->with(compact('bannerDetails'));
    }

    public function deleteBanner($id){
        Banner::where('id',$id)->delete();
        return redirect()->back()->with('flash_message_success', 'Banner Deleted');
    }

    public function deleteBannerImage($id){
        // Get Product Image
        $bannerImage = Banner::where('id',$id)->first();

        // Get Product Image Paths
        $image_path = 'images/banners/';
       

        // Delete Large Image if not exists in Folder
        if(file_exists($image_path.$bannerImage->image)){
            unlink($image_path.$bannerImage->image);
        }

        // Delete Image from blogs table
        Banner::where(['id'=>$id])->update(['image'=>'']);

        return redirect()->back()->with('flash_message_success', ' image has been deleted successfully');
    }

    public function testimonials(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();

            //echo "<pre>";print_r($data);die();
            $testimonial = new Testimonial;
            $testimonial->name = $data['name'];
            $testimonial->profession = $data['profession'];
            $testimonial->description = $data['Feedback'];

            if(empty($data['status'])){
                $status='0';
            }else{
                $status='1';
            }

            // Upload Image
            if($request->hasFile('image')){
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $testimonial_path = 'images/testimonials/'.$fileName;
                    Image::make($image_tmp)->resize(100, 100)->save($testimonial_path);
                    $testimonial->image = $fileName; 
                }
            }

            $testimonial->status = $status;
            $testimonial->save();
            return redirect()->back()->with('flash_message_success', 'Testimonial has been added successfully');
        
        }

        $testimonials = Testimonial::get();
        return view('admin.testimonial.index')->with(compact('testimonials'));
    }

    public function edittestimonial(Request $request, $id=null){
        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>"; print_r($data); die;

            
            // Upload Image
            if($request->hasFile('image')){
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $banner_path = 'images/testimonials/'.$fileName;
                    Image::make($image_tmp)->resize(100, 100)->save($banner_path); 
                }
            }else if(!empty($data['current_image'])){
                $fileName = $data['current_image'];
            }else{
                $fileName = null;
            }


            Testimonial::where('id',$id)->update([
                'status'=>$data['status'],
                'name'=>$data['name'], 
                'profession'=>$data['profession'],
                'image'=>$fileName,
                'description' => $data['Feedback'],
            ]);
            return redirect()->back()->with('flash_message_success','Testimonial has been edited Successfully');

        }

        $testimonial = Testimonial::where('id',$id)->first();
        return view('admin.testimonial.edit_testimonial')->with(compact('testimonial'));
    }

    public function deletetestimonialImage($id){
        // Get Product Image
        $testimonialImage = Testimonial::where('id',$id)->first();

        // Get Product Image Paths
        $image_path = 'images/testimonials/';
       

        // Delete Large Image if not exists in Folder
        if(file_exists($image_path.$testimonialImage->image)){
            unlink($image_path.$testimonialImage->image);
        }

        // Delete Image from blogs table
        Testimonial::where(['id'=>$id])->update(['image'=>null]);

        return redirect()->back()->with('flash_message_success', ' image has been deleted successfully');
    }

    public function deleteTestimonial($id){
        $testimonial = Testimonial::where('id',$id)->first();
        $testimonial->delete();
        return redirect()->back()->with('flash_message_success', 'Testimonial Deleted');
    }

    public function about(Request $request){
        if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>";print_r($data);die();

            //echo "<pre>";print_r($data);die();      
            $detail=$request->summernoteInput;
            libxml_use_internal_errors(true);
            $dom = new \domdocument();
            $dom->loadHtml($detail, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
            $images = $dom->getElementsByTagName('img');

            foreach($images as $k => $img){
                $src = $img->getattribute('src');

                if (preg_match('/data:img/', $src)) {
                    preg_match('/data:img\/(?<mime>.*?)\;/', $src, $groups);
                    $mimeType = $groups['mime'];
                    $path = '/images/' . uniqid('', true) . '.' . $mimeType;
                    file_put_cotents($path, file_get_contents($src));
                    $image->removeAttribute('src');
                    $image->setAttribute('src', url($path));
                }
           
            }

            $detail = $dom->savehtml();

            // Upload Image
            if($request->hasFile('image'))
            {
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) 
                {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $large_image_path = 'images/large'.'/'.$fileName;
                    $medium_image_path = 'images/medium'.'/'.$fileName;  
                    $small_image_path = 'images/small'.'/'.$fileName;  

                    Image::make($image_tmp)->save($large_image_path);
                    Image::make($image_tmp)->resize(600, 600)->save($medium_image_path);
                    Image::make($image_tmp)->resize(300, 300)->save($small_image_path);

                }
            }elseif(!empty($data['current_image']))
            {
                $fileName = $data['current_image'];
            }else
            {
                $fileName = '';
            }


            // Upload Image
            if($request->hasFile('bannerimage'))
            {
                $image_tmp = $request->bannerimage;
                if ($image_tmp->isValid()) 
                {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $bannerfileName = rand(111,99999).'.'.$extension;
                    $large_image_path = 'images/large'.'/'.$bannerfileName;
                    $medium_image_path = 'images/medium'.'/'.$bannerfileName;  
                    $small_image_path = 'images/small'.'/'.$bannerfileName;  

                    Image::make($image_tmp)->save($large_image_path);
                    Image::make($image_tmp)->resize(600, 600)->save($medium_image_path);
                    Image::make($image_tmp)->resize(300, 300)->save($small_image_path);

                }
            }elseif(!empty($data['current_banner_image']))
            {
                $bannerfileName = $data['current_banner_image'];
            }else
            {
                $bannerfileName = '';
            }


            About::where('id',1)->update([
                'homepage_heading' => $request->homepageheading,
                'image' => $fileName,
                'bannerimage'=>$bannerfileName,
                'bannerheading'=>$data['bannerheading'],
                'paypal_client_id'=>$data['paypal_client_id'],
                'paypal_secret_key'=>$data['paypal_secret_key'],
                'slogan'=>$data['slogan'],
                'about' => $detail
            ]);

            return redirect()->back()->with('flash_message_success','About Updated');
        }

        return view('admin.pages.about');
    }   


    public function sendContactEmail(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();
            /*echo "<pre>"; print_r($data); die;*/

            $validator = Validator::make($request->all(), [
                'name' => 'required|regex:/^[\pL\s\-]+$/u|max:255',
                'email' => 'required|email',
                'subject' => 'required',
            ]);

            if ($validator->fails()) {
                return redirect()->back()->withErrors($validator)->withInput();
            }

            $contact = new Contact;
            $contact->name = $data['name'];
            $contact->email = $data['email'];
            $contact->subject = $data['subject'];
            $contact->message = $data['message'];
            $contact->save();

            // Send Contact Email
            $email = 'mdshamshe747@gmail.com';
            $messageData = [
                'name'=>$data['name'],
                'email'=>$data['email'],
                'subject'=>$data['subject'],
                'comment'=>$data['message']
            ];
            Mail::send('emails.contact',$messageData,function($message)use($email){
                $message->to($email)->subject('Enquiry from samshtech Website');
            });



            return redirect()->back()->with('flash_message_success','Thanks for your enquiry. We will get back to you soon.');
        }
    }
    
    public function editfundraisingCategory(Request $request, $id){

        if($request->isMethod('post')){
            $data = $request->all();

            if($request->hasFile('image'))
            {
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) 
                {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $large_image_path = 'images/backend_images/category/large'.'/'.$fileName;
                    $medium_image_path = 'images/backend_images/category/medium'.'/'.$fileName;  
                    $small_image_path = 'images/backend_images/category/small'.'/'.$fileName;  

                    Image::make($image_tmp)->save($large_image_path);
                    Image::make($image_tmp)->resize(600, 600)->save($medium_image_path);
                    Image::make($image_tmp)->resize(300, 300)->save($small_image_path);

                }
                }elseif(!empty($data['current_image']))
                {
                    $fileName = $data['current_image'];
                }else
                {
                    $fileName = '';
                }

                Category::where(['id'=>$id])->update([
                    'name' => $data['name'],
                    'image' => $fileName,
                
                ]);

            
            return redirect()->back()->with('flash_message_success','Category Updated');
        }
        $category = Category::where('id',$id)->get()->first();
        return view('admin.fundraising.editCategory')->with(compact('category'));
    }

     public function deleteCategoryImage($id){
        // Get Product Image
        $category_Image = Category::where('id',$id)->first();

        // Get Product Image Paths
        $image_path = 'images/category/';
       

        // Delete Large Image if not exists in Folder
        if(file_exists($image_path.$category_Image->image)){
            unlink($image_path.$category_Image->image);
        }

        // Delete Image from blogs table
        Category::where(['id'=>$id])->update(['image'=>'']);

        return redirect()->back()->with('flash_message_success', ' image has been deleted successfully');
    }

    public function accountsettings(Request $request){

        if($request->isMethod('post')){
            
            $data = $request->all();
            //echo "<pre>"; print_r($data); die;
            $old_pwd = User::where('id',Auth::User()->id)->first();
            $current_pwd = $data['password'];
            if(Hash::check($current_pwd,$old_pwd->password)){
                // Update password
                $new_pwd = bcrypt($data['newpassword']);
                User::where('id',Auth::User()->id)->update([ 'password'=>$new_pwd, 'name'=>$data['name'],'mobile'=>$data['mobile']]);
                return redirect()->back()->with('flash_message_success',' Password updated successfully!');
            }else{
                return redirect()->back()->with('flash_message_error','Current Password is incorrect!');
            }
        
        }

        return view('admin.settings.accountsetting');
    }

    public function aboutsettings(Request $request){
        if($request->isMethod('post')){
            $data = $request->all();

            //echo "<pre>";print_r($data);die();      
            $detail=$request->summernoteInput;
            libxml_use_internal_errors(true);
            $dom = new \domdocument();
            $dom->loadHtml($detail, LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
            $images = $dom->getElementsByTagName('img');

            foreach($images as $k => $img){
                $src = $img->getattribute('src');

                if (preg_match('/data:img/', $src)) {
                    preg_match('/data:img\/(?<mime>.*?)\;/', $src, $groups);
                    $mimeType = $groups['mime'];
                    $path = '/images/' . uniqid('', true) . '.' . $mimeType;
                    file_put_cotents($path, file_get_contents($src));
                    $image->removeAttribute('src');
                    $image->setAttribute('src', url($path));
                }
           
            }

            $detail = $dom->savehtml();



            //echo "<pre>";print_r($data);
            About::where('id',1)->update([
                'mobile_no'=>$data['mobile_no'],
                'alternet_no'=>$data['alternet_no'],
                'email'=>$data['email'],
                'address'=>$data['address'],
                'address_link'=>$data['address_link'],
                'whatsapp_link'=>$data['whatsapp_link'],
                'instagram_link'=>$data['instagram_link'],
                'twitter_link'=>$data['twitter_link'],
                'facebook_link'=>$data['facebook_link'],
                'youtube_link'=>$data['youtube_link'],
                'about'=>$detail,
                'termsandcondition'=>$data['termsandcondition'],
                'privacypolicy'=>$data['privacypolicy'],
            ]);
            return redirect()->back()->with('flash_message_success','About Updated!');
        }

        return view('admin.settings.about');
    }


    public function withdrawalrequests(Request $request){

        if($request->isMethod('post')){

        }

        $withdrawalrequests = Withdraw::where('status', 0)->get();
        return view('admin.withdrawl.withdrawalrequests')->with(compact('withdrawalrequests'));

    }

    public function acceptwithdrawalrequest(Request $request, $id){

        Withdraw::where('id', $id)->update(['status'=> 1,'withdrawal_done'=>Carbon::now()]);



        $withdraw = Withdraw::where('id', $id)->first();

        Fundraising::where('id', $withdraw->fundraising_id)->update(['status'=>'Complete']);

        return redirect()->back()->with('flash_message_success','Withdraw Accepted');

    }
    public function withdrawn(){

        $withdrawns = Withdraw::where('status', 1)->get();
        return view('admin.withdrawl.withdrawn')->with(compact('withdrawns'));
    }

    public function deletewithdrawrequest($id){

        Withdraw::where('id', $id)->delete();
        return redirect()->back()->with('flash_message_success','Withdraw request deleted');
    }

}
