<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Fundraising;
use App\Donation;
use App\User;
use Auth;
use App\Document;
use App\Contact;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Mail;
use App\Blog;
use App\Category;
use App\Testimonial;
use Session;
use App\About;
use App\Banner;
use App\SubscriptionPlan;

class FrontendController extends Controller
{   
    public function index(){

        $about = About::where('id',1)->first();
        $plans = SubscriptionPlan::where('status',1)->get();
        $banners = Banner::where('status', 1)->get();
        $blogs = Blog::where('status',1)->get();
        $testimonials = Testimonial::where('status',1)->get();
        return view('index')->with(compact('about','plans','banners','blogs','testimonials'));

    }
    public function features(){

        $about = About::where('id',1)->first();
        return view('pages.features')->with(compact('about'));

    }
    public function integrations(){

        $about = About::where('id',1)->first();
        return view('pages.integrations')->with(compact('about'));

    }
    public function resources(){

        $about = About::where('id',1)->first();
        return view('pages.resources')->with(compact('about'));

    }
    public function pricing(){
        $plans = SubscriptionPlan::where('status',1)->get();
        $about = About::where('id',1)->first();
        return view('pages.pricing')->with(compact('about','plans'));

    }
    public function industry(){

        $about = About::where('id',1)->first();
        return view('pages.industry')->with(compact('about'));

    }
    public function partners(){
        $testimonials = Testimonial::where('status',1)->get();
        $about = About::where('id',1)->first();
        return view('pages.partners')->with(compact('about','testimonials'));

    }
    public function customer_center(){

        $about = About::where('id',1)->first();
        return view('pages.customer_center')->with(compact('about'));

    }


    public function contact(Request $request){
        if($request->isMethod('post')){
            /*echo "<pre>"; print_r($data); die;*/
            $data = $request->all();

            $validator = Validator::make($request->all(), [
                'name' => 'required|regex:/^[\pL\s\-]+$/u|max:255',
                'email' => 'required|email',
                'subject' => 'required',
            ]);

            if ($validator->fails()) {
                return redirect()->back()->withErrors($validator)->withInput();
            }

            $contact = new Contact;
            $contact->name = $data['name'];
            $contact->email = $data['email'];
            $contact->subject = $data['subject'];
            $contact->message = $data['message'];
            $contact->save();

            $about = About::where('id',1)->first();
            // Send Contact Email
            $email = $about->email;
            $messageData = [
                'name'=>$data['name'],
                'email'=>$data['email'],
                'subject'=>$data['subject'],
                'comment'=>$data['message']
            ];
            Mail::send('emails.contact',$messageData,function($message)use($email,$data){
                $message->to($email)->subject($data['subject']);
            });

            return redirect()->back()->with('flash_message_success','Contact Email sent');

        }

        return view('pages.customer_center');
    }
    public function blog_details($id){

        $blog = Blog::where('id', $id)->first();
        return view('blog_details')->with(compact('blog'));
    }

    public function blogPost($id){



        $blog = Blog::where('id', $id)->get()->first();
        $relatedBlogs = Blog::inRandomOrder()->where('id','!=',$id)->paginate(3);
        $meta_title = $blog->title;
        $meta_description = $blog->Description;

        return view('pages.blogPost')->with(compact('blog','relatedBlogs','meta_title','meta_description'));
    }

    public function category(Request $request, $id){
        
        $category = Category::where('id',$id)->get()->first();
        $fundraisings = Fundraising::where('category_id', $id)->orderBy('created_at','desc')->paginate(8);
        $no_of_fundraisings = Fundraising::where('category_id', $id)->count();
        return view('pages.categories')->with(compact('category','fundraisings','no_of_fundraisings'));
    }

    public function testimonials(){



        $testimonials = Testimonial::where('status',1)->orderBy('created_at','desc')->paginate(8);
        return view('pages.testimonial')->with(compact('testimonials'));
    }

    public function feedback(Request $request){

        if($request->isMethod('post')){
            $data = $request->all();

            //echo "<pre>";print_r($data);die();
            $testimonial = new Testimonial;
            $testimonial->name = $data['name'];
            $testimonial->profession = $data['proffession'];
            $testimonial->description = $data['feedback'];

            $status = 0;

            // Upload Image
            if($request->hasFile('image')){
                $image_tmp = $request->image;
                if ($image_tmp->isValid()) {
                    // Upload Images after Resize
                    $extension = $image_tmp->getClientOriginalExtension();
                    $fileName = rand(111,99999).'.'.$extension;
                    $testimonial_path = 'images/testimonials/'.$fileName;
                    Image::make($image_tmp)->resize(100, 100)->save($testimonial_path);
                    $testimonial->image = $fileName; 
                }
            }

            $testimonial->status = $status;
            $testimonial->save();
            return redirect()->back()->with('flash_message_success', 'Feedback Posted successfully');
        
        }

        return view('pages.feedback');
    }
}

