<?php

namespace App\Http\Controllers;
use Illuminate\Http\Request;
use Session;
use Auth;
use App\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class UsersController extends Controller
{	

	public function register(Request $request){
        if($request->isMethod('post')){
            $data = $request->all();
            /*echo "<pre>"; print_r($data); die;*/
            // Check if User already exists
            $usersCount = User::where('email',$data['email'])->count();
            if($usersCount>0){
                return redirect('/register')->with('flash_message_error','Email already exists!');
            }elseif ($data['password'] != $data['password_confirmation']) {
                return redirect('/register')->with('flash_message_error','Password and confirm password dont match');
            }
            else{


                $user = new User;
                $user->name = $data['name'];
                $user->email = $data['email'];
                $user->mobile = $data['mobile'];
                $user->user_type = 'User';
                //$user->address = $data['address'];
                $user->password = bcrypt($data['password']);
                date_default_timezone_set('Asia/Kuala_Lumpur');
                $user->created_at = date("Y-m-d H:i:s");
                $user->updated_at = date("Y-m-d H:i:s");
                $user->save();

                /*// Send Register Email
                $email = $data['email'];
                $messageData = ['email'=>$data['email'],'name'=>$data['name']];
                Mail::send('emails.register',$messageData,function($message) use($email){
                    $message->to($email)->subject('Registration with E-com Website');
                });*/

                // Send Confirmation Email
                $email = $data['email'];
                $messageData = ['email'=>$data['email'],'name'=>$data['name'],'code'=>base64_encode($data['email'])];
                Mail::send('emails.confirmation',$messageData,function($message) use($email){
                    $message->to($email)->subject('Confirm your Yemen Kasih Account');
                });

                return redirect('/register')->with('flash_message_success','Please confirm your email to activate your account!');

                
            }   
        }
        
        if(Session::has('adminSession')){
            return view('/admin/dashboard');
        }elseif (Session::has('frontSession')) {
            return view('/myaccount');
        }else{
         //   return redirect()->action('AdminController@login')->with('flash_message_error', 'Please Login');
             return view('auth.register');
        }  
    }

    public function confirmAccount($email){
        $email = base64_decode($email);
        $userCount = User::where('email',$email)->count();
        if($userCount > 0){
            $userDetails = User::where('email',$email)->first();
            if($userDetails->status == 1){
                return redirect('login')->with('flash_message_success','Your Email account is already activated. You can login now.');
            }else{
                User::where('email',$email)->update(['status'=>1]);

                // Send Welcome Email
                $messageData = ['email'=>$email,'name'=>$userDetails->name];
                Mail::send('emails.welcome',$messageData,function($message) use($email){
                    $message->to($email)->subject('Welcome to Yemen Kasih Website');
                });

                return redirect('login')->with('flash_message_success','Your Email account is activated. You can login now.');
            }
        }else{
            abort(404);
        }
    }

    public function login(Request $request){
    	if($request->isMethod('post')){
            $data = $request->all();
            //echo "<pre>"; print_r($data); die;
            if(Auth::attempt(['email'=>$data['email'],'password'=>$data['password'], 'user_type'=>'Admin'])){
                //echo "ok";die();
                $userStatus = User::where('email',$data['email'])->first();
                if($userStatus->status == 0){
                    return redirect('/login')->with('flash_message_error','Your account is not activated! Please confirm your Email to activate.');    
                }else{
                	Session::put('adminsession',$data['email']);
                    Session::put('usersession',$data['email']);
                	//$arr = array('msg'=>'Logged in successfully', 'status'=>true);
                	//return response()->json($arr);
                	return redirect('/admin');
                }
                
        	}elseif(Auth::attempt(['email'=>$data['email'], 'password'=>$data['password'] ])){

        		$userStatus = User::where('email',$data['email'])->first();
                if($userStatus->status == 0){
                    return redirect('/login')->with('flash_message_error','Your account is not activated! Please confirm your Email to activate.');    
                }else{
                    Session::put('usersession',$data['email']);
                	//$arr = array('msg'=>'Logged in successfully', 'status'=>true);
                	//return response()->json($arr);
                	return redirect('/users');
                }
        		
        	}else{
        		return redirect('/login')->with('flash_message_error','Invalid Username Or Password');
        	}        
    	}

    	if(Session::has('adminSession')){
            return redirect('/admin');
        }elseif (Session::has('usersession')) {
            return redirect('/users');
        }else{
         //   return redirect()->action('AdminController@login')->with('flash_message_error', 'Please Login');
             return view('auth.login');
        }  

    	
    }

    public function accountsettings(Request $request){

        if($request->isMethod('post')){
            
            $data = $request->all();
            //echo "<pre>"; print_r($data); die;
            $old_pwd = User::where('id',Auth::User()->id)->first();
            $current_pwd = $data['password'];
            if(Hash::check($current_pwd,$old_pwd->password)){
                // Update password
                $new_pwd = bcrypt($data['newpassword']);
                User::where('id',Auth::User()->id)->update([ 'password'=>$new_pwd, 'name'=>$data['name'],'mobile'=>$data['mobile'] ]);
                return redirect()->back()->with('flash_message_success',' Password updated successfully!');
            }else{
                return redirect()->back()->with('flash_message_error','Current Password is incorrect!');
            }
        
        }

        return view('users.settings.accountsetting');
    }

    public function logout(){
    	Auth::logout();
        Session::forget('usersession');
        Session::forget('adminsession');
        
        return redirect('/');
    }

    public function forgotPassword(Request $request){
        if($request->isMethod('post')){
            $data = $request->all();
            /*echo "<pre>"; print_r($data); die;*/
            $userCount = User::where('email',$data['email'])->count();
            if($userCount == 0){
                return redirect()->back()->with('flash_message_error','Email does not exists!');
            }

            //Get User Details
            $userDetails = User::where('email',$data['email'])->first();

            //Generate Random Password
            $random_password = Str::random(8);

            //Encode/Secure Password
            $new_password = bcrypt($random_password);

            //Update Password
            User::where('email',$data['email'])->update(['password'=>$new_password]);

            //Send Forgot Password Email Code
            $email = $data['email'];
            $name = $userDetails->name;
            $messageData = [
                'email'=>$email,
                'name'=>$name,
                'password'=>$random_password
            ];
            Mail::send('emails.forgotpassword',$messageData,function($message)use($email){
                $message->to($email)->subject('New Password - Olea Erp Website');
            });

            return redirect('/login')->with('flash_message_success','Please check your email for new password!');

        }
        return view('auth.forgotpassword');
    }



}
